@@ -12,7 +12,7 @@ package MooX::Options;
 
 use strict;
 use warnings;
-our $VERSION = '0.8';    # VERSION
+our $VERSION = '0.9';    # VERSION
 use Carp;
 use Data::Dumper;
 use Getopt::Long::Descriptive;
@@ -24,6 +24,7 @@ my %DEFAULT_OPTIONS = (
     'creation_method_name'  => 'new_with_options',
     'option_chain_method'   => 'has',
     'option_method_name'    => 'option',
+    'flavour'               => [],
 );
 
 my @FILTER = qw/format short repeatable negativable autosplit doc/;
@@ -154,9 +155,11 @@ sub import {
             #call describe_options
             my $usage_method
                 = $self->can("$import_options{option_method_name}_usage");
-            my ( $opt, $usage )
-                = describe_options( @Options,
-                [ "help|h", "show this help message" ] );
+            my ( $opt, $usage ) = describe_options(
+                @Options,
+                [ "help|h", "show this help message" ],
+                { getopt_conf => $import_options{flavour} }
+            );
             $Usage = $usage->text;
             $usage_method->(0) if $opt->help;
 
@@ -192,7 +195,7 @@ MooX::Options - add option keywords to your Moo object
 
 =head1 VERSION
 
-version 0.8
+version 0.9
 
 =head1 MooX::Options
 
@@ -238,6 +241,15 @@ don't filter extra params for MooX::Options before calling chain_method
 
 it is usefull if you want to use this params for something else
 
+=item flavour
+
+pass extra arguments for Getopt::Long::Descriptive.  it is usefull if you
+want to configure Getopt::Long.
+
+    use MooX::Options flavour => [qw( pass_through )];
+
+Any flavour is pass to L<Getopt::Long> as a configuration, check the doc to see what is possible.
+
 =back
 
 =back
